# eric7.MicroPython.ConvertToUF2Dialog

Module implementing a dialog to convert a .hex or .bin firmware file to .uf2.

### Global Attributes

None

### Classes

ConvertToUF2Dialog | Class implementing a dialog to convert a .hex or .bin firmware file to .uf2.

### Functions

None

## ConvertToUF2Dialog

Class implementing a dialog to convert a .hex or .bin firmware file to .uf2.

### Derived from

QDialog, Ui_ConvertToUF2Dialog

### Class Attributes

ConvertScript
FamiliesFile

### Class Methods

None

### Methods

ConvertToUF2Dialog | Constructor
__conversionFinished | Private slot handling the end of the conversion process.
__populateFamilyComboBox | Private method to populate the chip family combo box with values read from 'uf2families.json' file.
__readError | Private slot to read the standard error channel of the conversion process.
__readOutput | Private slot to read the standard output channel of the conversion process.
__updateConvertButton | Private method to set the enabled status of the 'Convert' button.
on_convertButton_clicked | Private slot activating the conversion process.
on_familiesComboBox_currentTextChanged | Private slot handling the selection of a chip family.
on_firmwarePicker_textChanged | Private slot handling a change of the firmware file name.

### Static Methods

None

#### ConvertToUF2Dialog (Constructor)

ConvertToUF2Dialog(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### ConvertToUF2Dialog.__conversionFinished

__conversionFinished(_exitCode, _exitStatus)

Private slot handling the end of the conversion process.

_exitCode (int)
  exit code of the process (unused)
_exitStatus (QProcess.ExitStatus)
  exit status of the process (unused)

#### ConvertToUF2Dialog.__populateFamilyComboBox

__populateFamilyComboBox()

Private method to populate the chip family combo box with values read from 'uf2families.json' file.

#### ConvertToUF2Dialog.__readError

__readError()

Private slot to read the standard error channel of the conversion process.

#### ConvertToUF2Dialog.__readOutput

__readOutput()

Private slot to read the standard output channel of the conversion process.

#### ConvertToUF2Dialog.__updateConvertButton

__updateConvertButton()

Private method to set the enabled status of the 'Convert' button.

#### ConvertToUF2Dialog.on_convertButton_clicked

on_convertButton_clicked()

Private slot activating the conversion process.

#### ConvertToUF2Dialog.on_familiesComboBox_currentTextChanged

on_familiesComboBox_currentTextChanged(family)

Private slot handling the selection of a chip family.

family (str)
  name of the selected chip family

#### ConvertToUF2Dialog.on_firmwarePicker_textChanged

on_firmwarePicker_textChanged(firmware)

Private slot handling a change of the firmware file name.

firmware (str)
  name of the firmware file

Up